PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/ParameterTab.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
ParameterTab.hpp
1#ifndef GYM_PCB_UI_PARAMETERTAB_H
2#define GYM_PCB_UI_PARAMETERTAB_H
3
4#include "Py.hpp"
5#include <QWidget>
6#include <map>
7#include <string>
8
9class QScrollArea;
10class QVBoxLayout;
11
12class Parameter;
13class GLWidget;
14
15 class ParameterTab : public QWidget
16{
17 Q_OBJECT
18public:
19 bool init();
20 void addParameters(const std::map<std::string, Parameter *>&);
21 void clear();
22private:
23 QScrollArea *mScroll;
24 QVBoxLayout *mLayout;
25};
26
27#endif // GYM_PCB_UI_PARAMETERTAB_H
GLWidget
Definition GLWidget.hpp:34
ParameterTab
Definition ParameterTab.hpp:16
Parameter
Definition Parameter.hpp:9